@@ -1,10 +1,14 @@
+{-# LANGUAGE CPP #-}
+
 module Program.Mighty.Resource (
     amIrootUser
   , setGroupUser
   , unlimit
   ) where
 
+#if __GLASGOW_HASKELL__ < 709
 import Control.Applicative
+#endif
 import Control.Exception
 import Control.Monad
 import System.Posix
