@@ -1,4 +1,5 @@
 {-# LANGUAGE OverloadedStrings, TupleSections #-}
+{-# LANGUAGE CPP #-}
 
 module Program.Mighty.Route (
   -- * Paring a routing file
@@ -18,7 +19,9 @@ module Program.Mighty.Route (
   , writeRouteDBRef
   ) where
 
+#if __GLASGOW_HASKELL__ < 709
 import Control.Applicative hiding (many,(<|>))
+#endif
 import Control.Monad
 import Data.ByteString
 import qualified Data.ByteString.Char8 as BS
