@@ -2,7 +2,9 @@
 
 module Main where
 
+#ifndef HTTP_OVER_TLS
 import Control.Monad (when)
+#endif
 import Data.Version (showVersion)
 import Network.Wai.Application.Classic hiding ((</>), (+++))
 import System.Directory (getCurrentDirectory)
@@ -70,7 +72,7 @@ main = do
         hPutStrLn stderr $ reportFile ++ " is not writable"
         hPrint stderr e
         exitFailure
-#ifdef TLS
+#ifdef HTTP_OVER_TLS
     checkTLS _ = return ()
 #else
     checkTLS opt = when (opt_service opt > 1) $ do
